@@ -27,28 +27,26 @@ impl<'a> fmt::Debug for Value<'a> {
 
 fn main() {
     println!("simple..");
-    let elm1: Node<&'static str, &'static str, &'static str, Value, ()> =
-        element(
-            "div",
-            vec![
-                attr("class", Value::Simple("container".to_string())),
-                attr("id", Value::Simple("elm1".to_string())),
-                attr("click", Value::Callback(&|x: usize| x.to_string())),
-            ],
-            vec![],
-        );
+    let elm1: Node<&'static str, &'static str, &'static str, Value> = element(
+        "div",
+        vec![
+            attr("class", Value::Simple("container".to_string())),
+            attr("id", Value::Simple("elm1".to_string())),
+            attr("click", Value::Callback(&|x: usize| x.to_string())),
+        ],
+        vec![],
+    );
     println!("elm1: {:#?}", elm1);
 
-    let elm2: Node<&'static str, &'static str, &'static str, Value, ()> =
-        element(
-            "div",
-            vec![
-                attr("class", Value::Simple("container".to_string())),
-                attr("id", Value::Simple("elm2".to_string())),
-                attr("click", Value::Callback(&|x: usize| x.to_string())),
-            ],
-            vec![],
-        );
+    let elm2: Node<&'static str, &'static str, &'static str, Value> = element(
+        "div",
+        vec![
+            attr("class", Value::Simple("container".to_string())),
+            attr("id", Value::Simple("elm2".to_string())),
+            attr("click", Value::Callback(&|x: usize| x.to_string())),
+        ],
+        vec![],
+    );
 
     let diff = diff_with_key(&elm1, &elm2, &"key");
     println!("patches: {:#?}", diff);
