@@ -40,10 +40,7 @@ fn key_1_removed_at_start() {
     let diff = diff_with_key(&old, &new, &"key");
     assert_eq!(
         diff,
-        vec![
-            RemoveNode::new(Some(&"div"), TreePath::start_at(1, vec![0, 0]),)
-                .into()
-        ]
+        vec![RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0]),).into()]
     );
 }
 
@@ -67,10 +64,7 @@ fn non_unique_keys_matched_at_old() {
     let diff = diff_with_key(&old, &new, &"key");
     assert_eq!(
         diff,
-        vec![
-            RemoveNode::new(Some(&"div"), TreePath::start_at(2, vec![0, 1]),)
-                .into()
-        ]
+        vec![RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1]),).into()]
     );
 }
 
@@ -94,10 +88,7 @@ fn key_2_removed_at_the_end() {
     let diff = diff_with_key(&old, &new, &"key");
     assert_eq!(
         diff,
-        vec![
-            RemoveNode::new(Some(&"div"), TreePath::start_at(2, vec![0, 1]),)
-                .into()
-        ]
+        vec![RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1]),).into()]
     );
 }
 
@@ -125,10 +116,7 @@ fn key_2_removed_at_the_middle() {
     let diff = diff_with_key(&old, &new, &"key");
     assert_eq!(
         diff,
-        vec![
-            RemoveNode::new(Some(&"div"), TreePath::start_at(2, vec![0, 1]),)
-                .into()
-        ]
+        vec![RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1]),).into()]
     );
 }
 
@@ -162,12 +150,11 @@ fn there_are_2_exact_same_keys_in_the_old() {
         vec![
             ChangeText::new(
                 &Text::new("0"),
-                TreePath::start_at(2, vec![0, 0, 0]),
+                TreePath::new(vec![0, 0, 0]),
                 &Text::new("1")
             )
             .into(),
-            RemoveNode::new(Some(&"div"), TreePath::start_at(3, vec![0, 1]),)
-                .into()
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 1]),).into()
         ]
     );
 }
@@ -202,13 +189,13 @@ fn there_are_2_exact_same_keys_in_the_new() {
         vec![
             ChangeText::new(
                 &Text::new("0"),
-                TreePath::start_at(2, vec![0, 0, 0]),
+                TreePath::new(vec![0, 0, 0]),
                 &Text::new("1")
             )
             .into(),
             InsertNode::new(
                 Some(&"main"),
-                TreePath::start_at(3, vec![0, 1]),
+                TreePath::new(vec![0, 1]),
                 &element("div", vec![attr("key", "1")], vec![text(1)])
             )
             .into(),
@@ -247,24 +234,23 @@ fn there_are_2_exact_same_keys_in_both_old_and_new() {
         vec![
             ChangeText::new(
                 &Text::new("0"),
-                TreePath::start_at(2, vec![0, 0, 0]),
+                TreePath::new(vec![0, 0, 0]),
                 &Text::new("1")
             )
             .into(),
             ChangeText::new(
                 &Text::new("1"),
-                TreePath::start_at(4, vec![0, 1, 0]),
+                TreePath::new(vec![0, 1, 0]),
                 &Text::new("3")
             )
             .into(),
             InsertNode::new(
                 Some(&"main"),
-                TreePath::start_at(3, vec![0, 1]),
+                TreePath::new(vec![0, 1]),
                 &element("div", vec![attr("key", "1")], vec![text(2)])
             )
             .into(),
-            RemoveNode::new(Some(&"div"), TreePath::start_at(5, vec![0, 2]),)
-                .into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 2]),).into(),
         ]
     );
 }
@@ -293,7 +279,7 @@ fn key_2_inserted_at_start() {
         diff,
         vec![InsertNode::new(
             Some(&"main"),
-            TreePath::start_at(1, vec![0, 0]),
+            TreePath::new(vec![0, 0]),
             &element("div", vec![attr("key", "2")], vec![])
         )
         .into()]
@@ -321,7 +307,7 @@ fn keyed_element_not_reused() {
         diff,
         vec![ReplaceNode::new(
             Some(&"div"),
-            TreePath::start_at(1, vec![0, 0]),
+            TreePath::new(vec![0, 0]),
             &element("div", vec![attr("key", "2")], vec![])
         )
         .into()]
@@ -353,8 +339,8 @@ fn key_2_inserted_at_the_end() {
         diff,
         vec![AppendChildren::new(
             &"main",
-            TreePath::start_at(0, vec![0]),
-            vec![(2, &element("div", vec![attr("key", "2")], vec![]))]
+            TreePath::new(vec![0]),
+            vec![&element("div", vec![attr("key", "2")], vec![])]
         )
         .into()]
     );
@@ -393,20 +379,14 @@ fn test_append_at_sub_level() {
         vec![
             AppendChildren::new(
                 &"main",
-                TreePath::start_at(1, vec![0, 0]),
-                vec![(
-                    4,
-                    &element("div", vec![attr("key", "2")], vec![text(2)])
-                ),],
+                TreePath::new(vec![0, 0]),
+                vec![&element("div", vec![attr("key", "2")], vec![text(2)]),],
             )
             .into(),
             AppendChildren::new(
                 &"main",
-                TreePath::start_at(1, vec![0, 0]),
-                vec![(
-                    6,
-                    &element("div", vec![attr("key", "3")], vec![text(3)])
-                )],
+                TreePath::new(vec![0, 0]),
+                vec![&element("div", vec![attr("key", "3")], vec![text(3)])],
             )
             .into()
         ]
@@ -442,7 +422,7 @@ fn key_2_inserted_in_the_middle() {
         diff,
         vec![InsertNode::new(
             Some(&"main"),
-            TreePath::start_at(2, vec![0, 1]),
+            TreePath::new(vec![0, 1]),
             &element("div", vec![attr("key", "2")], vec![])
         )
         .into()]
@@ -478,12 +458,11 @@ fn key1_removed_at_start_then_key2_has_additional_attributes() {
         vec![
             AddAttributes::new(
                 &"div",
-                TreePath::start_at(2, vec![0, 1]),
+                TreePath::new(vec![0, 1]),
                 vec![&attr("class", "some-class").into()]
             )
             .into(),
-            RemoveNode::new(Some(&"div"), TreePath::start_at(1, vec![0, 0]),)
-                .into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0]),).into(),
         ]
     );
 }
@@ -524,15 +503,11 @@ fn deep_nested_key1_removed_at_start_then_key2_has_additional_attributes() {
         vec![
             AddAttributes::new(
                 &"div",
-                    TreePath::start_at(3, vec![0, 0, 1]),
+                TreePath::new(vec![0, 0, 1]),
                 vec![&attr("class", "some-class").into()]
             )
             .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                TreePath::start_at(2, vec![0, 0, 0]),
-            )
-            .into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0, 0]),).into(),
         ]
     );
 }
@@ -575,20 +550,12 @@ fn deep_nested_more_children_key0_and_key1_removed_at_start_then_key2_has_additi
         vec![
             AddAttributes::new(
                 &"div",
-                    TreePath::start_at(4, vec![0, 0, 2]),
+                TreePath::new(vec![0, 0, 2]),
                 vec![&attr("class", "some-class").into()]
             )
             .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                TreePath::start_at(2, vec![0, 0, 0]),
-            )
-            .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                TreePath::start_at(3, vec![0, 0, 1]),
-            )
-            .into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0, 0]),).into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0, 1]),).into(),
         ]
     );
 }
@@ -652,32 +619,24 @@ fn deep_nested_keyed_with_non_keyed_children() {
         vec![
             AddAttributes::new(
                 &"div",
-                    TreePath::start_at(4, vec![0, 0, 2]),
+                TreePath::new(vec![0, 0, 2]),
                 vec![&attr("class", "some-class").into()]
             )
             .into(),
             ChangeText::new(
                 &Text::new("paragraph1"),
-                    TreePath::start_at(6, vec![0, 0, 2, 0, 0]),
+                TreePath::new(vec![0, 0, 2, 0, 0]),
                 &Text::new("paragraph1, with added content")
             )
             .into(),
             ChangeText::new(
                 &Text::new("Click here"),
-                    TreePath::start_at(8, vec![0, 0, 2, 1, 0]),
+                TreePath::new(vec![0, 0, 2, 1, 0]),
                 &Text::new("Click here to continue")
             )
             .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                TreePath::start_at(2, vec![0, 0, 0]),
-            )
-            .into(),
-            RemoveNode::new(
-                Some(&"div"),
-                TreePath::start_at(3, vec![0, 0, 1]),
-            )
-            .into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0, 0]),).into(),
+            RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0, 1]),).into(),
         ]
     );
 }
@@ -724,15 +683,12 @@ fn text_changed_in_keyed_elements() {
         vec![
             ChangeText::new(
                 &Text::new("item3"),
-                TreePath::start_at(7, vec![0, 0, 2, 0]),
+                TreePath::new(vec![0, 0, 2, 0]),
                 &Text::new("item3 with changes")
             )
             .into(),
-            RemoveNode::new(
-                Some(&"article"),
-                TreePath::start_at(2, vec![0, 0, 0]),
-            )
-            .into()
+            RemoveNode::new(Some(&"article"), TreePath::new(vec![0, 0, 0]),)
+                .into()
         ]
     );
 }
@@ -800,18 +756,15 @@ fn text_changed_in_mixed_keyed_and_non_keyed_elements() {
         vec![
             ChangeText::new(
                 &Text::new("item3"),
-                TreePath::start_at(7, vec![0, 0, 2, 0]),
+                TreePath::new(vec![0, 0, 2, 0]),
                 &Text::new("item3 with changes")
             )
             .into(),
-            RemoveNode::new(
-                Some(&"article"),
-                TreePath::start_at(2, vec![0, 0, 0]),
-            )
-            .into(),
+            RemoveNode::new(Some(&"article"), TreePath::new(vec![0, 0, 0]),)
+                .into(),
             ChangeText::new(
                 &Text::new("3 items left"),
-                TreePath::start_at(9, vec![0, 1, 0]),
+                TreePath::new(vec![0, 1, 0]),
                 &Text::new("2 items left")
             )
             .into(),
@@ -885,18 +838,15 @@ fn test12() {
         vec![
             ChangeText::new(
                 &Text::new("item3"),
-                TreePath::start_at(9, vec![0, 1, 2, 0]),
+                TreePath::new(vec![0, 1, 2, 0]),
                 &Text::new("item3 with changes")
             )
             .into(),
-            RemoveNode::new(
-                Some(&"article"),
-                TreePath::start_at(4, vec![0, 1, 0]),
-            )
-            .into(),
+            RemoveNode::new(Some(&"article"), TreePath::new(vec![0, 1, 0]),)
+                .into(),
             ChangeText::new(
                 &Text::new("3 items left"),
-                TreePath::start_at(11, vec![0, 2, 0]),
+                TreePath::new(vec![0, 2, 0]),
                 &Text::new("2 items left")
             )
             .into(),
@@ -929,9 +879,6 @@ fn remove_first() {
     dbg!(&diff);
     assert_eq!(
         diff,
-        vec![
-            RemoveNode::new(Some(&"div"), TreePath::start_at(1, vec![0, 0]),)
-                .into()
-        ]
+        vec![RemoveNode::new(Some(&"div"), TreePath::new(vec![0, 0]),).into()]
     )
 }
